diff --git a/include/text.php b/include/text.php
index 4636334e8..b34c3e902 100644
--- a/include/text.php
+++ b/include/text.php
@@ -1041,7 +1041,7 @@ function micropro($contact, $redirect = false, $class = '', $textmode = false) {
* @param string $url Search url.
* @param bool $save Show save search button.
* @param bool $aside Display the search widgit aside.
- *
+ *
* @return string Formatted HTML.
*/
function search($s, $id = 'search-box', $url = 'search', $save = false, $aside = true)
@@ -2106,7 +2106,8 @@ function text_highlight($s, $lang) {
}
$renderer = new Text_Highlighter_Renderer_Html($options);
- $hl = Text_Highlighter::factory($lang);
+ $factory = new Text_Highlighter();
+ $hl = $factory->factory($lang);
$hl->setRenderer($renderer);
$o = $hl->highlight($s);
$o = str_replace("\n", '', $o);
diff --git a/mod/contacts.php b/mod/contacts.php
index 54e9b5b64..f213b8370 100644
--- a/mod/contacts.php
+++ b/mod/contacts.php
@@ -1,7 +1,9 @@
page['aside'] = '';
}
+ $contact_id = null;
$contact = null;
if ((($a->argc == 2) && intval($a->argv[1])) || (($a->argc == 3) && intval($a->argv[1]) && ($a->argv[2] == "posts"))) {
$contact_id = intval($a->argv[1]);
@@ -164,11 +167,7 @@ function contacts_post(App $a)
return;
}
- $orig_record = q("SELECT * FROM `contact` WHERE `id` = %d AND `uid` = %d LIMIT 1",
- intval($contact_id),
- intval(local_user())
- );
- if (!DBM::is_result($orig_record)) {
+ if (!dba::exists('contact', ['id' => $contact_id, 'uid' => local_user()])) {
notice(t('Could not access contact record.') . EOL);
goaway('contacts');
return; // NOTREACHED
@@ -178,11 +177,7 @@ function contacts_post(App $a)
$profile_id = intval($_POST['profile-assign']);
if ($profile_id) {
- $r = q("SELECT `id` FROM `profile` WHERE `id` = %d AND `uid` = %d LIMIT 1",
- intval($profile_id),
- intval(local_user())
- );
- if (!DBM::is_result($r)) {
+ if (!dba::exists('profile', ['id' => $profile_id, 'uid' => local_user()])) {
notice(t('Could not locate selected profile.') . EOL);
return;
}
@@ -229,6 +224,7 @@ function contacts_post(App $a)
return;
}
+
/* contact actions */
function _contact_update($contact_id)
@@ -764,7 +760,6 @@ function contacts_content(App $a)
$total = 0;
$searching = false;
$search_hdr = null;
- $search_txt = '';
if ($search) {
$searching = true;
$search_hdr = $search;
diff --git a/mod/credits.php b/mod/credits.php
index e0e834388..a501dee1f 100644
--- a/mod/credits.php
+++ b/mod/credits.php
@@ -5,19 +5,17 @@
* (only contributors to the git repositories for friendica core and the
* addons repository will be listed though ATM)
*/
-
use Friendica\App;
-function credits_content(App $a) {
+function credits_content()
+{
/* fill the page with credits */
- $f = fopen('util/credits.txt', 'r');
- $names = fread($f, filesize('util/credits.txt'));
- $arr = explode("\n", htmlspecialchars($names));
- fclose($f);
+ $credits_string = file_get_contents('util/credits.txt');
+ $names = explode("\n", htmlspecialchars($credits_string));
$tpl = get_markup_template('credits.tpl');
- return replace_macros($tpl, array(
+ return replace_macros($tpl, [
'$title' => t('Credits'),
'$thanks' => t('Friendica is a community project, that would not be possible without the help of many people. Here is a list of those who have contributed to the code or the translation of Friendica. Thank you all!'),
- '$names' => $arr,
- ));
+ '$names' => $names,
+ ]);
}
diff --git a/mod/crepair.php b/mod/crepair.php
index 12bfc302f..94d161dc5 100644
--- a/mod/crepair.php
+++ b/mod/crepair.php
@@ -16,26 +16,17 @@ function crepair_init(App $a)
return;
}
- $contact_id = 0;
-
+ $contact = null;
if (($a->argc == 2) && intval($a->argv[1])) {
- $contact_id = intval($a->argv[1]);
- $r = q("SELECT * FROM `contact` WHERE `uid` = %d and `id` = %d LIMIT 1",
- intval(local_user()),
- intval($contact_id)
- );
- if (!DBM::is_result($r)) {
- $contact_id = 0;
- }
+ $contact = dba::selectFirst('contact', [], ['uid' => local_user(), 'id' => $a->argv[1]]);
}
if (!x($a->page, 'aside')) {
$a->page['aside'] = '';
}
- if ($contact_id) {
- $a->data['contact'] = $r[0];
- $contact = $r[0];
+ if (DBM::is_result($contact)) {
+ $a->data['contact'] = $contact;
profile_load($a, "", 0, Contact::getDetailsByURL($contact["url"]));
}
}
@@ -48,19 +39,15 @@ function crepair_post(App $a)
$cid = (($a->argc > 1) ? intval($a->argv[1]) : 0);
+ $contact = null;
if ($cid) {
- $r = q("SELECT * FROM `contact` WHERE `id` = %d AND `uid` = %d LIMIT 1",
- intval($cid),
- intval(local_user())
- );
+ $contact = dba::selectFirst('contact', [], ['id' => $cid, 'uid' => local_user()]);
}
- if (!DBM::is_result($r)) {
+ if (!DBM::is_result($contact)) {
return;
}
- $contact = $r[0];
-
$name = defaults($_POST, 'name' , $contact['name']);
$nick = defaults($_POST, 'nick' , '');
$url = defaults($_POST, 'url' , '');
@@ -113,20 +100,16 @@ function crepair_content(App $a)
$cid = (($a->argc > 1) ? intval($a->argv[1]) : 0);
+ $contact = null;
if ($cid) {
- $r = q("SELECT * FROM `contact` WHERE `id` = %d AND `uid` = %d LIMIT 1",
- intval($cid),
- intval(local_user())
- );
+ $contact = dba::selectFirst('contact', [], ['id' => $cid, 'uid' => local_user()]);
}
- if (!DBM::is_result($r)) {
+ if (!DBM::is_result($contact)) {
notice(t('Contact not found.') . EOL);
return;
}
- $contact = $r[0];
-
$warning = t('WARNING: This is highly advanced and if you enter incorrect information your communications with this contact may stop working.');
$info = t('Please use your browser \'Back\' button now if you are uncertain what to do on this page.');
diff --git a/mod/delegate.php b/mod/delegate.php
index 684ae19a8..0168c763e 100644
--- a/mod/delegate.php
+++ b/mod/delegate.php
@@ -4,130 +4,118 @@ use Friendica\App;
use Friendica\Core\System;
use Friendica\Database\DBM;
-require_once('mod/settings.php');
+require_once 'mod/settings.php';
-function delegate_init(App $a) {
+function delegate_init(App $a)
+{
return settings_init($a);
}
-function delegate_content(App $a) {
-
- if (! local_user()) {
- notice( t('Permission denied.') . EOL);
+function delegate_content(App $a)
+{
+ if (!local_user()) {
+ notice(t('Permission denied.') . EOL);
return;
}
if ($a->argc > 2 && $a->argv[1] === 'add' && intval($a->argv[2])) {
-
// delegated admins can view but not change delegation permissions
-
- if (x($_SESSION,'submanage') && intval($_SESSION['submanage'])) {
+ if (x($_SESSION, 'submanage')) {
goaway(System::baseUrl() . '/delegate');
}
- $id = $a->argv[2];
+ $user_id = $a->argv[2];
- $r = q("select `nickname` from user where uid = %d limit 1",
- intval($id)
- );
- if (DBM::is_result($r)) {
- $r = q("select id from contact where uid = %d and nurl = '%s' limit 1",
- intval(local_user()),
- dbesc(normalise_link(System::baseUrl() . '/profile/' . $r[0]['nickname']))
- );
- if (DBM::is_result($r)) {
- dba::insert('manage', array('uid' => $a->argv[2], 'mid' => local_user()));
+ $user = dba::selectFirst('user', ['nickname'], ['uid' => $user_id]);
+ if (DBM::is_result($user)) {
+ $condition = [
+ 'uid' => local_user(),
+ 'nurl' => normalise_link(System::baseUrl() . '/profile/' . $user['nickname'])
+ ];
+ if (dba::exists('contact', $condition)) {
+ dba::insert('manage', ['uid' => $user_id, 'mid' => local_user()]);
}
}
goaway(System::baseUrl() . '/delegate');
}
if ($a->argc > 2 && $a->argv[1] === 'remove' && intval($a->argv[2])) {
-
// delegated admins can view but not change delegation permissions
- if (x($_SESSION,'submanage') && intval($_SESSION['submanage'])) {
+ if (x($_SESSION, 'submanage')) {
goaway(System::baseUrl() . '/delegate');
}
- q("DELETE FROM `manage` WHERE `uid` = %d AND `mid` = %d LIMIT 1",
- intval($a->argv[2]),
- intval(local_user())
- );
+ dba::delete('manage', ['uid' => $a->argv[2], 'mid' => local_user()]);
goaway(System::baseUrl() . '/delegate');
-
}
- $full_managers = array();
-
// These people can manage this account/page with full privilege
-
+ $full_managers = [];
$r = q("SELECT * FROM `user` WHERE `email` = '%s' AND `password` = '%s' ",
dbesc($a->user['email']),
dbesc($a->user['password'])
);
- if (DBM::is_result($r))
+ if (DBM::is_result($r)) {
$full_managers = $r;
-
- $delegates = array();
+ }
// find everybody that currently has delegated management to this account/page
-
- $r = q("select * from user where uid in ( select uid from manage where mid = %d ) ",
+ $delegates = [];
+ $r = q("SELECT * FROM `user` WHERE `uid` IN (SELECT `uid` FROM `manage` WHERE `mid` = %d)",
intval(local_user())
);
-
- if (DBM::is_result($r))
+ if (DBM::is_result($r)) {
$delegates = $r;
+ }
- $uids = array();
+ $uids = [];
+ foreach ($full_managers as $rr) {
+ $uids[] = $rr['uid'];
+ }
- if(count($full_managers))
- foreach($full_managers as $rr)
- $uids[] = $rr['uid'];
-
- if(count($delegates))
- foreach($delegates as $rr)
- $uids[] = $rr['uid'];
+ foreach ($delegates as $rr) {
+ $uids[] = $rr['uid'];
+ }
// find every contact who might be a candidate for delegation
- $r = q("select nurl from contact where substring_index(contact.nurl,'/',3) = '%s'
- and contact.uid = %d and contact.self = 0 and network = '%s' ",
+ $r = q("SELECT `nurl`
+ FROM `contact`
+ WHERE `self` = 0
+ AND SUBSTRING_INDEX(`nurl`, '/', 3) = '%s'
+ AND `uid` = %d
+ AND `network` = '%s' ",
dbesc(normalise_link(System::baseUrl())),
intval(local_user()),
dbesc(NETWORK_DFRN)
);
-
- if (! DBM::is_result($r)) {
- notice( t('No potential page delegates located.') . EOL);
+ if (!DBM::is_result($r)) {
+ notice(t('No potential page delegates located.') . EOL);
return;
}
- $nicknames = array();
+ $nicknames = [];
+ foreach ($r as $rr) {
+ $nicknames[] = "'" . dbesc(basename($rr['nurl'])) . "'";
+ }
+ $potentials = [];
+
+ $nicks = implode(',', $nicknames);
+
+ // get user records for all potential page delegates who are not already delegates or managers
+ $r = q("SELECT `uid`, `username`, `nickname` FROM `user` WHERE `nickname` IN ($nicks)");
if (DBM::is_result($r)) {
foreach ($r as $rr) {
- $nicknames[] = "'" . dbesc(basename($rr['nurl'])) . "'";
+ if (!in_array($rr['uid'], $uids)) {
+ $potentials[] = $rr;
+ }
}
}
- $potentials = array();
-
- $nicks = implode(',',$nicknames);
-
- // get user records for all potential page delegates who are not already delegates or managers
-
- $r = q("select `uid`, `username`, `nickname` from user where nickname in ( $nicks )");
-
- if (DBM::is_result($r))
- foreach($r as $rr)
- if(! in_array($rr['uid'],$uids))
- $potentials[] = $rr;
-
- require_once("mod/settings.php");
settings_init($a);
- $o = replace_macros(get_markup_template('delegate.tpl'),array(
+ $o = replace_macros(get_markup_template('delegate.tpl'), [
'$header' => t('Delegate Page Management'),
'$base' => System::baseUrl(),
'$desc' => t('Delegates are able to manage all aspects of this account/page except for basic account settings. Please do not delegate your personal account to anybody that you do not trust completely.'),
@@ -140,10 +128,8 @@ function delegate_content(App $a) {
'$remove' => t('Remove'),
'$add' => t('Add'),
'$none' => t('No entries.')
- ));
+ ]);
return $o;
-
-
}
diff --git a/mod/dfrn_confirm.php b/mod/dfrn_confirm.php
index a5f5f1bd3..8baacf093 100644
--- a/mod/dfrn_confirm.php
+++ b/mod/dfrn_confirm.php
@@ -4,15 +4,15 @@
* @file mod/dfrn_confirm.php
* @brief Module: dfrn_confirm
* Purpose: Friendship acceptance for DFRN contacts
- *.
+ *
* There are two possible entry points and three scenarios.
- *.
+ *
* 1. A form was submitted by our user approving a friendship that originated elsewhere.
* This may also be called from dfrn_request to automatically approve a friendship.
*
* 2. We may be the target or other side of the conversation to scenario 1, and will
* interact with that process on our own user's behalf.
- *.
+ *
* @see PDF with dfrn specs: https://github.com/friendica/friendica/blob/master/spec/dfrn2.pdf
* You also find a graphic which describes the confirmation process at
* https://github.com/friendica/friendica/blob/master/spec/dfrn2_contact_confirmation.png
@@ -32,110 +32,100 @@ use Friendica\Protocol\Diaspora;
use Friendica\Util\Crypto;
require_once 'include/enotify.php';
+require_once 'include/items.php';
-function dfrn_confirm_post(App $a, $handsfree = null) {
-
- if(is_array($handsfree)) {
-
+function dfrn_confirm_post(App $a, $handsfree = null)
+{
+ $node = null;
+ if (is_array($handsfree)) {
/*
* We were called directly from dfrn_request due to automatic friend acceptance.
* Any $_POST parameters we may require are supplied in the $handsfree array.
*
*/
-
$node = $handsfree['node'];
$a->interactive = false; // notice() becomes a no-op since nobody is there to see it
-
- }
- else {
- if($a->argc > 1)
- $node = $a->argv[1];
+ } elseif ($a->argc > 1) {
+ $node = $a->argv[1];
}
- /*
- *
- * Main entry point. Scenario 1. Our user received a friend request notification (perhaps
- * from another site) and clicked 'Approve'.
- * $POST['source_url'] is not set. If it is, it indicates Scenario 2.
- *
- * We may also have been called directly from dfrn_request ($handsfree != null) due to
- * this being a page type which supports automatic friend acceptance. That is also Scenario 1
- * since we are operating on behalf of our registered user to approve a friendship.
- *
- */
-
- if(! x($_POST,'source_url')) {
-
- $uid = ((is_array($handsfree)) ? $handsfree['uid'] : local_user());
-
- if(! $uid) {
- notice( t('Permission denied.') . EOL );
+ /*
+ * Main entry point. Scenario 1. Our user received a friend request notification (perhaps
+ * from another site) and clicked 'Approve'.
+ * $POST['source_url'] is not set. If it is, it indicates Scenario 2.
+ *
+ * We may also have been called directly from dfrn_request ($handsfree != null) due to
+ * this being a page type which supports automatic friend acceptance. That is also Scenario 1
+ * since we are operating on behalf of our registered user to approve a friendship.
+ */
+ if (!x($_POST, 'source_url')) {
+ $uid = defaults($handsfree, 'uid', local_user());
+ if (!$uid) {
+ notice(t('Permission denied.') . EOL);
return;
}
- $user = q("SELECT * FROM `user` WHERE `uid` = %d LIMIT 1",
- intval($uid)
- );
-
- if(! $user) {
- notice( t('Profile not found.') . EOL );
+ $user = dba::selectFirst('user', [], ['uid' => $uid]);
+ if (!DBM::is_result($user)) {
+ notice(t('Profile not found.') . EOL);
return;
}
-
// These data elements may come from either the friend request notification form or $handsfree array.
-
- if(is_array($handsfree)) {
+ if (is_array($handsfree)) {
logger('Confirm in handsfree mode');
- $dfrn_id = $handsfree['dfrn_id'];
- $intro_id = $handsfree['intro_id'];
- $duplex = $handsfree['duplex'];
- $hidden = ((array_key_exists('hidden',$handsfree)) ? intval($handsfree['hidden']) : 0 );
- $activity = ((array_key_exists('activity',$handsfree)) ? intval($handsfree['activity']) : 0 );
- }
- else {
- $dfrn_id = ((x($_POST,'dfrn_id')) ? notags(trim($_POST['dfrn_id'])) : "");
- $intro_id = ((x($_POST,'intro_id')) ? intval($_POST['intro_id']) : 0 );
- $duplex = ((x($_POST,'duplex')) ? intval($_POST['duplex']) : 0 );
- $cid = ((x($_POST,'contact_id')) ? intval($_POST['contact_id']) : 0 );
- $hidden = ((x($_POST,'hidden')) ? intval($_POST['hidden']) : 0 );
- $activity = ((x($_POST,'activity')) ? intval($_POST['activity']) : 0 );
+ $dfrn_id = $handsfree['dfrn_id'];
+ $intro_id = $handsfree['intro_id'];
+ $duplex = $handsfree['duplex'];
+ $cid = 0;
+ $hidden = intval(defaults($handsfree, 'hidden' , 0));
+ $activity = intval(defaults($handsfree, 'activity', 0));
+ } else {
+ $dfrn_id = notags(trim(defaults($_POST, 'dfrn_id' , '')));
+ $intro_id = intval(defaults($_POST, 'intro_id' , 0));
+ $duplex = intval(defaults($_POST, 'duplex' , 0));
+ $cid = intval(defaults($_POST, 'contact_id', 0));
+ $hidden = intval(defaults($_POST, 'hidden' , 0));
+ $activity = intval(defaults($_POST, 'activity' , 0));
}
/*
- *
* Ensure that dfrn_id has precedence when we go to find the contact record.
* We only want to search based on contact id if there is no dfrn_id,
* e.g. for OStatus network followers.
- *
*/
-
- if(strlen($dfrn_id))
+ if (strlen($dfrn_id)) {
$cid = 0;
+ }
logger('Confirming request for dfrn_id (issued) ' . $dfrn_id);
- if($cid)
+ if ($cid) {
logger('Confirming follower with contact_id: ' . $cid);
-
+ }
/*
- *
* The other person will have been issued an ID when they first requested friendship.
* Locate their record. At this time, their record will have both pending and blocked set to 1.
* There won't be any dfrn_id if this is a network follower, so use the contact_id instead.
- *
*/
-
- $r = q("SELECT * FROM `contact` WHERE ( ( `issued-id` != '' AND `issued-id` = '%s' ) OR ( `id` = %d AND `id` != 0 ) ) AND `uid` = %d AND `duplex` = 0 LIMIT 1",
+ $r = q("SELECT *
+ FROM `contact`
+ WHERE (
+ (`issued-id` != '' AND `issued-id` = '%s')
+ OR
+ (`id` = %d AND `id` != 0)
+ )
+ AND `uid` = %d
+ AND `duplex` = 0
+ LIMIT 1",
dbesc($dfrn_id),
intval($cid),
intval($uid)
);
-
- if (! DBM::is_result($r)) {
+ if (!DBM::is_result($r)) {
logger('Contact not found in DB.');
- notice( t('Contact not found.') . EOL );
- notice( t('This may occasionally happen if contact was requested by both persons and it has already been approved.') . EOL );
+ notice(t('Contact not found.') . EOL);
+ notice(t('This may occasionally happen if contact was requested by both persons and it has already been approved.') . EOL);
return;
}
@@ -149,38 +139,33 @@ function dfrn_confirm_post(App $a, $handsfree = null) {
$network = ((strlen($contact['issued-id'])) ? NETWORK_DFRN : NETWORK_OSTATUS);
- if($contact['network'])
+ if ($contact['network']) {
$network = $contact['network'];
+ }
- if($network === NETWORK_DFRN) {
-
+ if ($network === NETWORK_DFRN) {
/*
- *
* Generate a key pair for all further communications with this person.
* We have a keypair for every contact, and a site key for unknown people.
* This provides a means to carry on relationships with other people if
* any single key is compromised. It is a robust key. We're much more
* worried about key leakage than anybody cracking it.
- *
*/
$res = Crypto::newKeypair(4096);
-
$private_key = $res['prvkey'];
$public_key = $res['pubkey'];
// Save the private key. Send them the public key.
-
- $r = q("UPDATE `contact` SET `prvkey` = '%s' WHERE `id` = %d AND `uid` = %d",
+ q("UPDATE `contact` SET `prvkey` = '%s' WHERE `id` = %d AND `uid` = %d",
dbesc($private_key),
intval($contact_id),
intval($uid)
);
- $params = array();
+ $params = [];
/*
- *
* Per the DFRN protocol, we will verify both ends by encrypting the dfrn_id with our
* site private key (person on the other end can decrypt it with our site public key).
* Then encrypt our profile URL with the other person's site public key. They can decrypt
@@ -191,39 +176,41 @@ function dfrn_confirm_post(App $a, $handsfree = null) {
* If other site is willing to accept full encryption, (aes_allow is 1 AND we have php5.3
* or later) then we encrypt the personal public key we send them using AES-256-CBC and a
* random key which is encrypted with their site public key.
- *
*/
$src_aes_key = openssl_random_pseudo_bytes(64);
$result = '';
- openssl_private_encrypt($dfrn_id, $result, $user[0]['prvkey']);
+ openssl_private_encrypt($dfrn_id, $result, $user['prvkey']);
$params['dfrn_id'] = bin2hex($result);
$params['public_key'] = $public_key;
-
- $my_url = System::baseUrl() . '/profile/' . $user[0]['nickname'];
+ $my_url = System::baseUrl() . '/profile/' . $user['nickname'];
openssl_public_encrypt($my_url, $params['source_url'], $site_pubkey);
$params['source_url'] = bin2hex($params['source_url']);
- if($aes_allow && function_exists('openssl_encrypt')) {
+ if ($aes_allow && function_exists('openssl_encrypt')) {
openssl_public_encrypt($src_aes_key, $params['aes_key'], $site_pubkey);
$params['aes_key'] = bin2hex($params['aes_key']);
- $params['public_key'] = bin2hex(openssl_encrypt($public_key,'AES-256-CBC',$src_aes_key));
+ $params['public_key'] = bin2hex(openssl_encrypt($public_key, 'AES-256-CBC', $src_aes_key));
}
- $params['dfrn_version'] = DFRN_PROTOCOL_VERSION ;
- if($duplex == 1)
+ $params['dfrn_version'] = DFRN_PROTOCOL_VERSION;
+ if ($duplex == 1) {
$params['duplex'] = 1;
+ }
- if($user[0]['page-flags'] == PAGE_COMMUNITY)
+ if ($user['page-flags'] == PAGE_COMMUNITY) {
$params['page'] = 1;
- if($user[0]['page-flags'] == PAGE_PRVGROUP)
- $params['page'] = 2;
+ }
- logger('Confirm: posting data to ' . $dfrn_confirm . ': ' . print_r($params,true), LOGGER_DATA);
+ if ($user['page-flags'] == PAGE_PRVGROUP) {
+ $params['page'] = 2;
+ }
+
+ logger('Confirm: posting data to ' . $dfrn_confirm . ': ' . print_r($params, true), LOGGER_DATA);
/*
*
@@ -240,104 +227,91 @@ function dfrn_confirm_post(App $a, $handsfree = null) {
// Now figure out what they responded. Try to be robust if the remote site is
// having difficulty and throwing up errors of some kind.
- $leading_junk = substr($res,0,strpos($res,'status;
$message = unxmlify($xml->message); // human readable text of what may have gone wrong.
- switch($status) {
+ switch ($status) {
case 0:
- info( t("Confirmation completed successfully.") . EOL);
- if(strlen($message))
- notice( t('Remote site reported: ') . $message . EOL);
+ info(t("Confirmation completed successfully.") . EOL);
break;
case 1:
// birthday paradox - generate new dfrn-id and fall through.
$new_dfrn_id = random_string();
- $r = q("UPDATE contact SET `issued-id` = '%s' WHERE `id` = %d AND `uid` = %d",
+ q("UPDATE contact SET `issued-id` = '%s' WHERE `id` = %d AND `uid` = %d",
dbesc($new_dfrn_id),
intval($contact_id),
intval($uid)
);
case 2:
- notice( t("Temporary failure. Please wait and try again.") . EOL);
- if(strlen($message))
- notice( t('Remote site reported: ') . $message . EOL);
+ notice(t("Temporary failure. Please wait and try again.") . EOL);
break;
-
-
case 3:
- notice( t("Introduction failed or was revoked.") . EOL);
- if(strlen($message))
- notice( t('Remote site reported: ') . $message . EOL);
+ notice(t("Introduction failed or was revoked.") . EOL);
break;
- }
+ }
- if(($status == 0) && ($intro_id)) {
+ if (strlen($message)) {
+ notice(t('Remote site reported: ') . $message . EOL);
+ }
+ if (($status == 0) && ($intro_id)) {
// Success. Delete the notification.
-
- $r = q("DELETE FROM `intro` WHERE `id` = %d AND `uid` = %d",
+ q("DELETE FROM `intro` WHERE `id` = %d AND `uid` = %d",
intval($intro_id),
intval($uid)
);
-
}
- if($status != 0)
+ if ($status != 0) {
return;
+ }
}
-
/*
- *
* We have now established a relationship with the other site.
* Let's make our own personal copy of their profile photo so we don't have
* to always load it from their site.
*
* We will also update the contact record with the nature and scope of the relationship.
- *
*/
-
Contact::updateAvatar($contact['photo'], $uid, $contact_id);
logger('dfrn_confirm: confirm - imported photos');
- if($network === NETWORK_DFRN) {
-
+ if ($network === NETWORK_DFRN) {
$new_relation = CONTACT_IS_FOLLOWER;
- if(($relation == CONTACT_IS_SHARING) || ($duplex))
+ if (($relation == CONTACT_IS_SHARING) || ($duplex)) {
$new_relation = CONTACT_IS_FRIEND;
+ }
- if(($relation == CONTACT_IS_SHARING) && ($duplex))
+ if (($relation == CONTACT_IS_SHARING) && ($duplex)) {
$duplex = 0;
+ }
$r = q("UPDATE `contact` SET `rel` = %d,
`name-date` = '%s',
@@ -357,42 +331,36 @@ function dfrn_confirm_post(App $a, $handsfree = null) {
intval($contact_id)
);
} else {
-
// $network !== NETWORK_DFRN
-
- $network = (($contact['network']) ? $contact['network'] : NETWORK_OSTATUS);
- $notify = (($contact['notify']) ? $contact['notify'] : '');
- $poll = (($contact['poll']) ? $contact['poll'] : '');
+ $network = defaults($contact, 'network', NETWORK_OSTATUS);
$arr = Probe::uri($contact['url']);
- if (empty($contact['notify'])) {
- $notify = $arr['notify'];
- }
- if (empty($contact['poll'])) {
- $poll = $arr['poll'];
- }
+
+ $notify = defaults($contact, 'notify' , $arr['notify']);
+ $poll = defaults($contact, 'poll' , $arr['poll']);
$addr = $arr['addr'];
$new_relation = $contact['rel'];
$writable = $contact['writable'];
- if($network === NETWORK_DIASPORA) {
- if($duplex)
+ if ($network === NETWORK_DIASPORA) {
+ if ($duplex) {
$new_relation = CONTACT_IS_FRIEND;
- else
+ } else {
$new_relation = CONTACT_IS_FOLLOWER;
+ }
- if($new_relation != CONTACT_IS_FOLLOWER)
+ if ($new_relation != CONTACT_IS_FOLLOWER) {
$writable = 1;
+ }
}
- $r = q("DELETE FROM `intro` WHERE `id` = %d AND `uid` = %d",
+ q("DELETE FROM `intro` WHERE `id` = %d AND `uid` = %d",
intval($intro_id),
intval($uid)
);
-
$r = q("UPDATE `contact` SET `name-date` = '%s',
`uri-date` = '%s',
`addr` = '%s',
@@ -420,67 +388,43 @@ function dfrn_confirm_post(App $a, $handsfree = null) {
}
/// @TODO is DBM::is_result() working here?
- if ($r === false) {
- notice( t('Unable to set contact photo.') . EOL);
+ if (!DBM::is_result($r)) {
+ notice(t('Unable to set contact photo.') . EOL);
}
// reload contact info
-
- $r = q("SELECT * FROM `contact` WHERE `id` = %d LIMIT 1",
- intval($contact_id)
- );
- if (DBM::is_result($r)) {
- $contact = $r[0];
- } else {
- $contact = null;
- }
-
-
+ $contact = dba::selectFirst('contact', [], ['id' => $contact_id]);
if ((isset($new_relation) && $new_relation == CONTACT_IS_FRIEND)) {
-
- if (($contact) && ($contact['network'] === NETWORK_DIASPORA)) {
- $ret = Diaspora::sendShare($user[0],$r[0]);
+ if (DBM::is_result($contact) && ($contact['network'] === NETWORK_DIASPORA)) {
+ $ret = Diaspora::sendShare($user, $contact);
logger('share returns: ' . $ret);
}
// Send a new friend post if we are allowed to...
-
- $r = q("SELECT `hide-friends` FROM `profile` WHERE `uid` = %d AND `is-default` = 1 LIMIT 1",
- intval($uid)
- );
-
- if((DBM::is_result($r)) && ($r[0]['hide-friends'] == 0) && ($activity) && (! $hidden)) {
-
- require_once 'include/items.php';
-
- $self = q("SELECT * FROM `contact` WHERE `self` = 1 AND `uid` = %d LIMIT 1",
- intval($uid)
- );
-
- if(count($self)) {
-
- $arr = array();
+ $profile = dba::selectFirst('profile', ['hide-friends'], ['is-default' => true, 'uid' => $uid]);
+ if (x($profile, 'hide-friends') === 0 && $activity && !$hidden) {
+ $self = dba::selectFirst('contact', [], ['self' => true, 'uid' => $uid]);
+ if (DBM::is_result($self)) {
+ $arr = [];
$arr['guid'] = get_guid(32);
$arr['uri'] = $arr['parent-uri'] = item_new_uri($a->get_hostname(), $uid);
$arr['uid'] = $uid;
- $arr['contact-id'] = $self[0]['id'];
+ $arr['contact-id'] = $self['id'];
$arr['wall'] = 1;
$arr['type'] = 'wall';
$arr['gravity'] = 0;
$arr['origin'] = 1;
- $arr['author-name'] = $arr['owner-name'] = $self[0]['name'];
- $arr['author-link'] = $arr['owner-link'] = $self[0]['url'];
- $arr['author-avatar'] = $arr['owner-avatar'] = $self[0]['thumb'];
-
- $A = '[url=' . $self[0]['url'] . ']' . $self[0]['name'] . '[/url]';
- $APhoto = '[url=' . $self[0]['url'] . ']' . '[img]' . $self[0]['thumb'] . '[/img][/url]';
+ $arr['author-name'] = $arr['owner-name'] = $self['name'];
+ $arr['author-link'] = $arr['owner-link'] = $self['url'];
+ $arr['author-avatar'] = $arr['owner-avatar'] = $self['thumb'];
+ $A = '[url=' . $self['url'] . ']' . $self['name'] . '[/url]';
$B = '[url=' . $contact['url'] . ']' . $contact['name'] . '[/url]';
$BPhoto = '[url=' . $contact['url'] . ']' . '[img]' . $contact['thumb'] . '[/img][/url]';
$arr['verb'] = ACTIVITY_FRIEND;
$arr['object-type'] = ACTIVITY_OBJ_PERSON;
- $arr['body'] = sprintf( t('%1$s is now friends with %2$s'), $A, $B)."\n\n\n".$BPhoto;
+ $arr['body'] = t('%1$s is now friends with %2$s', $A, $B) . "\n\n\n" . $BPhoto;
$arr['object'] = '
diff --git a/include/dba.php b/include/dba.php
index 32fa88d95..986509369 100644
--- a/include/dba.php
+++ b/include/dba.php
@@ -852,24 +852,24 @@ class dba {
/**
* @brief Delete a row from a table
*
* @param string $table Table name
* @param array $param parameter array
* @param boolean $in_process Internal use: Only do a commit after the last delete
* @param array $callstack Internal use: prevent endless loops
*
- * @return boolean|array was the delete successfull? When $in_process is set: deletion data
+ * @return boolean|array was the delete successful? When $in_process is set: deletion data
*/
- public static function delete($table, $param, $in_process = false, &$callstack = array()) {
-
- if (empty($table) || empty($param)) {
- logger('Table and condition have to be set');
+ public static function delete($table, array $conditions, $in_process = false, array &$callstack = [])
+ {
+ if (empty($table) || empty($conditions)) {
+ logger('Table and conditions have to be set');
return false;
}
- $commands = array();
+ $commands = [];
// Create a key for the loop prevention
- $key = $table.':'.implode(':', array_keys($param)).':'.implode(':', $param);
+ $key = $table . ':' . implode(':', array_keys($conditions)) . ':' . implode(':', $conditions);
// We quit when this key already exists in the callstack.
if (isset($callstack[$key])) {
@@ -880,7 +880,7 @@ class dba {
$table = self::escape($table);
- $commands[$key] = array('table' => $table, 'param' => $param);
+ $commands[$key] = ['table' => $table, 'conditions' => $conditions];
// To speed up the whole process we cache the table relations
if (count(self::$relation) == 0) {
@@ -894,24 +894,24 @@ class dba {
$rel_def = array_values(self::$relation[$table])[0];
// Create a key for preventing double queries
- $qkey = $field.'-'.$table.':'.implode(':', array_keys($param)).':'.implode(':', $param);
+ $qkey = $field . '-' . $table . ':' . implode(':', array_keys($conditions)) . ':' . implode(':', $conditions);
// When the search field is the relation field, we don't need to fetch the rows
// This is useful when the leading record is already deleted in the frontend but the rest is done in the backend
- if ((count($param) == 1) && ($field == array_keys($param)[0])) {
+ if ((count($conditions) == 1) && ($field == array_keys($conditions)[0])) {
foreach ($rel_def AS $rel_table => $rel_fields) {
foreach ($rel_fields AS $rel_field) {
- $retval = self::delete($rel_table, array($rel_field => array_values($param)[0]), true, $callstack);
+ $retval = self::delete($rel_table, array($rel_field => array_values($conditions)[0]), true, $callstack);
$commands = array_merge($commands, $retval);
}
}
- // We quit when this key already exists in the callstack.
+ // We quit when this key already exists in the callstack.
} elseif (!isset($callstack[$qkey])) {
$callstack[$qkey] = true;
// Fetch all rows that are to be deleted
- $data = self::select($table, array($field), $param);
+ $data = self::select($table, array($field), $conditions);
while ($row = self::fetch($data)) {
// Now we accumulate the delete commands
@@ -934,24 +934,24 @@ class dba {
self::transaction();
}
- $compacted = array();
- $counter = array();
+ $compacted = [];
+ $counter = [];
foreach ($commands AS $command) {
- $condition = $command['param'];
- $array_element = each($condition);
+ $conditions = $command['conditions'];
+ $array_element = each($conditions);
$array_key = $array_element['key'];
if (is_int($array_key)) {
- $condition_string = " WHERE ".array_shift($condition);
+ $condition_string = " WHERE " . array_shift($conditions);
} else {
- $condition_string = " WHERE `".implode("` = ? AND `", array_keys($condition))."` = ?";
+ $condition_string = " WHERE `" . implode("` = ? AND `", array_keys($conditions)) . "` = ?";
}
- if ((count($command['param']) > 1) || is_int($array_key)) {
- $sql = "DELETE FROM `".$command['table']."`".$condition_string;
- logger(self::replace_parameters($sql, $condition), LOGGER_DATA);
+ if ((count($command['conditions']) > 1) || is_int($array_key)) {
+ $sql = "DELETE FROM `" . $command['table'] . "`" . $condition_string;
+ logger(self::replace_parameters($sql, $conditions), LOGGER_DATA);
- if (!self::e($sql, $condition)) {
+ if (!self::e($sql, $conditions)) {
if ($do_transaction) {
self::rollback();
}
@@ -959,25 +959,25 @@ class dba {
}
} else {
$key_table = $command['table'];
- $key_param = array_keys($command['param'])[0];
- $value = array_values($command['param'])[0];
+ $key_condition = array_keys($command['conditions'])[0];
+ $value = array_values($command['conditions'])[0];
// Split the SQL queries in chunks of 100 values
// We do the $i stuff here to make the code better readable
- $i = $counter[$key_table][$key_param];
- if (count($compacted[$key_table][$key_param][$i]) > 100) {
+ $i = $counter[$key_table][$key_condition];
+ if (count($compacted[$key_table][$key_condition][$i]) > 100) {
++$i;
}
- $compacted[$key_table][$key_param][$i][$value] = $value;
- $counter[$key_table][$key_param] = $i;
+ $compacted[$key_table][$key_condition][$i][$value] = $value;
+ $counter[$key_table][$key_condition] = $i;
}
}
foreach ($compacted AS $table => $values) {
foreach ($values AS $field => $field_value_list) {
foreach ($field_value_list AS $field_values) {
- $sql = "DELETE FROM `".$table."` WHERE `".$field."` IN (".
- substr(str_repeat("?, ", count($field_values)), 0, -2).");";
+ $sql = "DELETE FROM `" . $table . "` WHERE `" . $field . "` IN (" .
+ substr(str_repeat("?, ", count($field_values)), 0, -2) . ");";
logger(self::replace_parameters($sql, $field_values), LOGGER_DATA);
@@ -852,24 +852,24 @@ class dba {
* @brief Delete a row from a table
*
- * @param string $table Table name
- * @param array $param parameter array
- * @param boolean $in_process Internal use: Only do a commit after the last delete
- * @param array $callstack Internal use: prevent endless loops
+ * @param string $table Table name
+ * @param array $conditions Field condition(s)
+ * @param boolean $in_process Internal use: Only do a commit after the last delete
+ * @param array $callstack Internal use: prevent endless loops
*